y0 |release| Documentation
==========================

.. toctree::
   :maxdepth: 2
   :caption: Getting Started
   :name: start

   installation
   dsl
   parser
   graph
   examples
   mutation
   conditional_independence
   identification
   transport
   lvdags
   struct
   cli

Indices and Tables
------------------
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
